@@ -4,8 +4,17 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 
+use http::Uri;
+use url::Url;
+
 use crate::api::{ApiError, Client};
 
+pub fn url_to_http_uri(url: Url) -> Uri {
+    url.as_str()
+        .parse::<Uri>()
+        .expect("failed to parse a url::Url as an http::Uri")
+}
+
 /// A trait which represents a query which may be made to a GitLab client.
 pub trait Query<T, C>
 where
