@@ -288,6 +288,12 @@ pub enum MergeRequestAction {
     /// The merge request was reopened.
     #[serde(rename = "reopen")]
     Reopen,
+    /// The merge request was approved.
+    #[serde(rename = "approved")]
+    Approved,
+    /// A merge request approval was revoked.
+    #[serde(rename = "unapproved")]
+    Unapproved,
     /// The merge request was merged.
     #[serde(rename = "merge")]
     Merge,
@@ -734,8 +740,7 @@ impl<'de> Deserialize<'de> for WebHook {
         let val = <Value as Deserialize>::deserialize(deserializer)?;
 
         let object_kind = match val.pointer("/object_kind") {
-            // XXX(1.36.0): NLL makes this clone unnecessary.
-            Some(&Value::String(ref kind)) => kind.clone(),
+            Some(&Value::String(ref kind)) => kind,
             Some(_) => {
                 return Err(D::Error::invalid_type(
                     Unexpected::Other("JSON value"),
